@@ -6,14 +6,14 @@ from sql import Null, Literal, For
 from sql.aggregate import Sum
 from sql.conditionals import Coalesce
 
+from trytond.i18n import gettext
 from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
 from trytond.tools import grouped_slice, reduce_ids
 
-
-__all__ = ['Party', 'PartyErase']
+from trytond.modules.party.exceptions import EraseError
 
 
 class Party(metaclass=PoolMeta):
@@ -29,11 +29,13 @@ class Party(metaclass=PoolMeta):
         pool = Pool()
         MoveLine = pool.get('account.move.line')
         Account = pool.get('account.account')
+        AccountType = pool.get('account.account.type')
         User = pool.get('res.user')
         cursor = Transaction().connection.cursor()
 
         line = MoveLine.__table__()
         account = Account.__table__()
+        account_type = AccountType.__table__()
 
         values = {p.id: Decimal(0) for p in parties}
 
@@ -46,18 +48,19 @@ class Party(metaclass=PoolMeta):
 
         for sub_parties in grouped_slice(parties):
             party_clause = reduce_ids(line.party, [p.id for p in sub_parties])
-            cursor.execute(*line.join(account,
-                    condition=account.id == line.account
-                    ).select(line.party,
+            cursor.execute(*line
+                .join(account, condition=account.id == line.account)
+                .join(account_type, condition=account.type == account_type.id)
+                .select(line.party,
                     # Use credit - debit to positive deposit amount
                     Sum(Coalesce(line.credit, 0) - Coalesce(line.debit, 0)),
-                    where=(account.kind == 'deposit')
+                    where=account_type.deposit
                     & party_clause
                     & (line.reconciliation == Null)
                     & (account.company == user.company.id)
                     & line_clause,
                     group_by=line.party))
-            for party_id, value in cursor.fetchall():
+            for party_id, value in cursor:
                 # SQLite uses float for SUM
                 if not isinstance(value, Decimal):
                     value = currency.round(Decimal(str(value)))
@@ -69,10 +72,12 @@ class Party(metaclass=PoolMeta):
         pool = Pool()
         MoveLine = pool.get('account.move.line')
         Account = pool.get('account.account')
+        AccountType = pool.get('account.account.type')
         User = pool.get('res.user')
 
         line = MoveLine.__table__()
         account = Account.__table__()
+        account_type = AccountType.__table__()
 
         user = User(Transaction().user)
         if not user.company:
@@ -81,10 +86,12 @@ class Party(metaclass=PoolMeta):
         line_clause, _ = MoveLine.query_get(line)
         Operator = fields.SQL_OPERATORS[clause[1]]
 
-        query = line.join(account, condition=account.id == line.account
-            ).select(line.party,
+        query = (line
+            .join(account, condition=account.id == line.account)
+            .join(account_type, condition=account.type == account_type.id)
+            .select(line.party,
                 where=account.active
-                & (account.kind == 'deposit')
+                & account_type.deposit
                 & (line.party != Null)
                 & (line.reconciliation == Null)
                 & (account.company == user.company.id)
@@ -92,7 +99,7 @@ class Party(metaclass=PoolMeta):
                 group_by=line.party,
                 having=Operator(
                     Sum(Coalesce(line.debit, 0) - Coalesce(line.credit, 0)),
-                    Decimal(clause[2] or 0)))
+                    Decimal(clause[2] or 0))))
         return [('id', 'in', query)]
 
     def get_deposit_balance(self, deposit_account):
@@ -103,7 +110,7 @@ class Party(metaclass=PoolMeta):
         cursor = transaction.connection.cursor()
 
         line = MoveLine.__table__()
-        assert deposit_account.kind == 'deposit'
+        assert deposit_account.type.deposit
 
         where = ((line.account == deposit_account.id)
             & (line.party == self.id)
@@ -132,21 +139,12 @@ class Party(metaclass=PoolMeta):
         return not amount or ((amount < 0) == (sign < 0))
 
 
-class PartyErase(metaclass=PoolMeta):
+class Erase(metaclass=PoolMeta):
     __name__ = 'party.erase'
 
-    @classmethod
-    def __setup__(cls):
-        super(PartyErase, cls).__setup__()
-        cls._error_messages.update({
-                'deposit': (
-                    'The party "%(party)s" can not be erased '
-                    'because he has deposit for the company "%(company)s".'),
-                })
-
     def check_erase_company(self, party, company):
         if party.deposit:
-            self.raise_user_error('deposit', {
-                    'party': party.rec_name,
-                    'company': company.rec_name,
-                    })
+            raise EraseError(
+                gettext('account_deposit.msg_erase_party_deposit',
+                    party=party.rec_name,
+                    company=company.rec_name))
