@@ -4,11 +4,15 @@ import unittest
 import doctest
 from trytond.tests.test_tryton import suite as test_suite
 from trytond.tests.test_tryton import ModuleTestCase
-from trytond.tests.test_tryton import doctest_setup, doctest_teardown
+from trytond.tests.test_tryton import doctest_teardown
 from trytond.tests.test_tryton import doctest_checker
 
+from trytond.modules.company.tests import (
+    PartyCompanyCheckEraseMixin, CompanyTestMixin)
 
-class AccountDepositTestCase(ModuleTestCase):
+
+class AccountDepositTestCase(
+        PartyCompanyCheckEraseMixin, CompanyTestMixin, ModuleTestCase):
     'Test Account Deposit module'
     module = 'account_deposit'
 
@@ -18,7 +22,7 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             AccountDepositTestCase))
     suite.addTests(doctest.DocFileSuite('scenario_deposit.rst',
-            setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
+            tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
